@@ -30,7 +30,7 @@ def set_my_path(pyname, folder ):
 
 # Find path of the required file. Output: root path
 def find_my_file(filename):
-    for root, dirs, files in os.walk("C:\Spider_project"):
+    for root, dirs, files in os.walk("C:\spider-circadian-clock-model"):
         for name in files:
             if name == filename:
                 your_file = os.path.abspath(os.path.join(root, name))
